@@ -7,6 +7,11 @@ sub BUILDARGS {
     return { name => $args[0], version => $args[1], pathname => $args[2] };
 }
 
+sub version_format {
+    my $self = shift;
+    defined $self->version ? $self->version : 'undef';
+}
+
 1;
 
 
